@@ -81,8 +81,11 @@ def version():
         - `BaseListView`再次简化, 默认`filter_fields`改为`__all__`,        # 2.7.5
         - 默认`auto_generate_serializer_class`改为True
         - 增加`default_page_size`字段, 且`default_page_size`为`__all__`时, 返回全部数据
+        - 代码整理              # 2.7.6
+        - 增加`flat_dc_ls`功能, 可以将返回的dc_ls展平为list
+        - 取消`distinct_field_ls`和`order_type_ls`的捆绑      # 2.7.7
     """
-    v = "2.7.5"
+    v = "2.7.7"     # 查看当前已发布版本: https://pypi.org/search/?q=bddjango
     return v
 
 
