@@ -78,7 +78,7 @@ def get_key_from_request_data_or_self_obj(request_data, self_obj, key, get_type=
         ret_0 = getattr(self_obj, key) if hasattr(self_obj, key) else None
         ret_1 = pure.convert_query_parameter_to_bool(value) if value else None
         ret = ret_1 if ret_1 is not None else ret_0
-        return ret
+        return bool(ret)
     else:
         value = query_dc.get(key)
 
@@ -98,16 +98,6 @@ def set_query_dc_value(query_dc: (QueryDict, dict), new_dc: dict):
     return query_dc
 
 
-def get_ls_a_different_ls_b(a, b, keep_sort=True):
-    """
-    列表a和列表b的差集a-b, 并保留a列表原顺序
-    """
-    ret = list(set(a) - set(b))
-    if keep_sort:
-        ret.sort(key=a.index)
-    return ret
-
-
 def get_field_names_by_model(model_class, field_attr='name', exclude_fields=None):
     """
     获得`model_class.meta`中的字段名属性
@@ -126,7 +116,7 @@ def get_field_names_by_model(model_class, field_attr='name', exclude_fields=None
 
     if exclude_fields:
         assert isinstance(exclude_fields, (list, tuple)), '`exclude_fields`必须为list或tuple类型!'
-        field_names = get_ls_a_different_ls_b(field_names, exclude_fields, keep_sort=True)
+        field_names = pure.SetUtils.get_ls_a_different_ls_b(field_names, exclude_fields, keep_sort=True)
     return field_names
 
 
