@@ -1,5 +1,6 @@
 from .utils import *
 from rest_framework.views import APIView
+from .mixins import MyCreateModelMixin, MyUpdateModelMixin, MyDestroyModelMixin
 
 
 class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
@@ -15,9 +16,7 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
 
     _name = 'BaseListView'  # 这个在自动生成wiki时要用到
 
-    # renderer_classes = (StateMsgResultJSONRenderer,)
     # renderer_classes = APIView.renderer_classes + [StateMsgResultJSONRenderer]
-
     pagination_class = Pagination
 
     filter_fields = '__all__'  # '__all__'过滤所有. 精确检索的过滤字段, 如果过滤条件复杂的话, 建议重写
@@ -50,6 +49,8 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     default_page_size = None        # 默认每页返回的数量
     # add_host_prefix_to_media_url = True                                    # 是否返回文件的时候加上当前域名的prefix
 
+    flat_dc_ls = False      # 是否展平为list然后返回. 只有在返回一个字段的时候才生效.
+
     def __new__(cls, *args, **kwargs):
         ret = super().__new__(cls, *args, **kwargs)
 
@@ -307,18 +308,20 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
             assert isinstance(distinct_field_ls, (list, tuple)), 'distinct_field_ls因为list或者tuple!'
             qs_ls = qs_ls.order_by(*distinct_field_ls).distinct(*distinct_field_ls)  # bug: distinct_field_ls 后的字段无法排序
 
-        # order_by操作
-        if pure.convert_query_parameter_to_bool(order_type_ls):
-            if distinct_field_ls and distinct_field_ls not in ['__None__', ['__None__']]:
-                qs_ls = self.queryset.filter(pk__in=qs_ls.values('pk'))
+        # region # --- `order_by`操作
+        if not pure.convert_query_parameter_to_bool(order_type_ls):
+            order_type_ls = ['pk']
 
-            try:
-                qs_ls = order_by_order_type_ls(qs_ls, order_type_ls)
-            except ValueError as e:
-                msg = f'参数order_type_ls指定的排序字段[{order_type_ls}]排序失败! 更多信息: {str(e)}'
-                raise ValueError(msg)
-        else:
-            qs_ls = order_by_order_type_ls(qs_ls, ['pk'])       # 默认按照pk排序
+        # 要注意进行distinct之后的排序
+        if distinct_field_ls and distinct_field_ls not in ['__None__', ['__None__']]:
+            qs_ls = self.queryset.filter(pk__in=qs_ls.values('pk'))
+
+        try:
+            qs_ls = order_by_order_type_ls(qs_ls, order_type_ls)
+        except ValueError as e:
+            msg = f'参数order_type_ls指定的排序字段[{order_type_ls}]排序失败! 更多信息: {str(e)}'
+            raise ValueError(msg)
+        # endregion
 
         self.queryset = qs_ls
         return self.queryset
@@ -434,10 +437,15 @@ class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         serializer_class = self.get_serializer_class()
         resp, page_dc = paginate_qsls_to_dcls(self.queryset, serializer_class, page=p, per_page=page_size,
                                               context=context)
-        ret = self._conv_data_format(resp, page_dc)
+        ret = self.conv_data_format(resp, page_dc)
         return ret
 
-    def conv_data_format(self, data: (dict, Response), page_dc):
+    def conv_data_format(self, data, page_dc):
+        # --- 是否展平为list, 而不是dc_ls
+        flat_dc_ls = get_key_from_request_data_or_self_obj(self.get_request_data(), self, 'flat_dc_ls', get_type='bool')
+        if flat_dc_ls and data and len(data[0]) == 1:
+            data = [list(i.values())[0] for i in data]
+
         ret = {
             'page_dc': page_dc,
             'data': data,
@@ -507,9 +515,6 @@ class BaseList(BaseListView):  # 向下兼容, 返回格式调整, 重写_conv_d
         return ret
 
 
-from .mixins import MyCreateModelMixin, MyUpdateModelMixin, MyDestroyModelMixin
-
-
 class CompleteModelView(BaseListView, MyCreateModelMixin, MyUpdateModelMixin, MyDestroyModelMixin):
     """
     * 一个模型的增删改查全套接口
@@ -646,36 +651,3 @@ class CompleteModelView(BaseListView, MyCreateModelMixin, MyUpdateModelMixin, My
         ret, status, msg = self.get_list_ret(request, *args, **kwargs)
         return APIResponse(ret, status=status, msg=msg)
 
-
-class DecoratorBaseListView(BaseListView):
-    @api_decorator
-    def get(self, request, *args, **kwargs):
-        return super().get(*args, **kwargs)
-
-    @api_decorator
-    def post(self, request, *args, **kwargs):
-        return super().post(*args, **kwargs)
-
-
-class DecoratorCompleteModelView(CompleteModelView):
-    """
-    全部用api_decorator装饰
-    """
-
-    @api_decorator
-    def get(self, request, *args, **kwargs):
-        return super().get(*args, **kwargs)
-
-    @api_decorator
-    def post(self, *args, **kwargs):
-        return super().post(*args, **kwargs)
-
-    @api_decorator
-    def put(self, request, *args, **kwargs):
-        return super().put(*args, **kwargs)
-
-    @api_decorator
-    def delete(self, request, *args, **kwargs):
-        return super().delete(*args, **kwargs)
-
-
